#!/usr/bin/python

# $Id: progress.py 43 2008-02-20 17:38:01Z ae $
#
# Copyright (C) 2007 Andreas Engel
#
# This is a nearly 1:1 translation from C++ to Python of
# boost::progress_display and therefore distributed under the Boost
# Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt
# or copy at http://www.boost.org/LICENSE_1_0.txt).

import sys

class ProgressDisplay:

    def __init__(self, expected_count, os=sys.stdout, s1="\n", s2="", s3=""):
        self.__os = os
        self.__s1 = s1
        self.__s2 = s2
        self.__s3 = s3
        self.restart(expected_count)

    def restart(self, expected_count):
        self.__count = self.__next_tic_count = self.__tic = 0
        self.__expected_count = expected_count

        self.__os.write("%s0%%" % self.__s1)
        for i in xrange(10,100,10):
            self.__os.write("   %d" % i)
        self.__os.write("   100%%\n%s" % self.__s2)
        self.__os.write("|%s\n" % ("----|" * 10))
        self.__os.write(self.__s3)
        self.__os.flush()
        if not self.__expected_count:
            self.__expected_count = 1

    def count(self):
        return self.__count

    def expected_count(self):
        return self.__expected_count

    def __iadd__(self, increment):
        if self.__count >= self.__expected_count:
            return
        self.__count += increment
        if self.__count >= self.__next_tic_count:
            self.__display_tic()
        return self

    def __display_tic(self):
        tics_needed = (float(self.__count) / self.__expected_count) * 50.0
        self.__os.write("*")
        self.__tic += 1
        while self.__tic < tics_needed:
            self.__os.write("*")
            self.__tic += 1
        self.__next_tic_count = int((self.__tic/50.0)*self.__expected_count)
        if self.__count >= self.__expected_count:
            if self.__tic < 51:
                self.__os.write("*")
            self.__os.write("\n")
        self.__os.flush()

# test
if __name__ == '__main__':
    def testme(maxvalue, increment):
        show_progress = ProgressDisplay(maxvalue, sys.stderr)
        for i in xrange(0, maxvalue, increment):
            show_progress += increment
    testme(4711, 250)
    testme(5000, 250)
    testme(5000, 1)
